@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -18,6 +18,8 @@
 
 import logging
 
+from locale import gettext as _
+
 from catfish_lib.AboutDialog import AboutDialog
 
 logger = logging.getLogger('catfish')
@@ -32,3 +34,4 @@ class AboutCatfishDialog(AboutDialog):
     def finish_initializing(self, builder):  # pylint: disable=E1002
         """Set up the about dialog"""
         super(AboutCatfishDialog, self).finish_initializing(builder)
+        self.set_translator_credits(_("translator-credits"))
